@@ -1,6 +1,6 @@
 package Dist::Zilla;
 {
-  $Dist::Zilla::VERSION = '4.300005';
+  $Dist::Zilla::VERSION = '4.300020';
 }
 # ABSTRACT: distribution builder; installer not included!
 use Moose 0.92; # role composition fixes
@@ -517,6 +517,7 @@ __PACKAGE__->meta->make_immutable;
 1;
 
 
+__END__
 =pod
 
 =head1 NAME
@@ -525,7 +526,7 @@ Dist::Zilla - distribution builder; installer not included!
 
 =head1 VERSION
 
-version 4.300005
+version 4.300020
 
 =head1 DESCRIPTION
 
@@ -698,19 +699,62 @@ There is a mailing list to discuss Dist::Zilla.  You can L<join the
 list|http://www.listbox.com/subscribe/?list_id=139292> or L<browse the
 archives|http://listbox.com/member/archive/139292>.
 
+=head1 SEE ALSO
+
+=over 4
+
+=item *
+
+In the Dist::Zilla distribution:
+
+=over 4
+
+=item *
+
+Plugin bundles:
+L<@Basic|Dist::Zilla::PluginBundle::Basic>,
+L<@Filter|Dist::Zilla::PluginBundle::Filter>.
+
+=item *
+
+Major plugins:
+L<GatherDir|Dist::Zilla::Plugin::GatherDir>,
+L<Prereqs|Dist::Zilla::Plugin::Prereqs>,
+L<AutoPrereqs|Dist::Zilla::Plugin::AutoPrereqs>,
+L<MetaYAML|Dist::Zilla::Plugin::MetaYAML>,
+L<MetaYAML|Dist::Zilla::Plugin::MetaJSON>,
+...
+
+=back
+
+=item *
+
+On the CPAN:
+
+=over 4
+
+=item *
+
+Search for plugins: L<https://metacpan.org/search?q=Dist::Zilla::Plugin::>
+
+=item *
+
+Search for plugin bundles: L<https://metacpan.org/search?q=Dist::Zilla::PluginBundle::>
+
+=back
+
+=back
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Ricardo SIGNES.
+This software is copyright (c) 2012 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-
-__END__
-
