@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Dist::Zilla::App;
 {
-  $Dist::Zilla::App::VERSION = '4.300005';
+  $Dist::Zilla::App::VERSION = '4.300020';
 }
 # ABSTRACT: Dist::Zilla's App::Cmd
 use App::Cmd::Setup 0.309 -app; # better compilation error detection
@@ -27,6 +27,9 @@ sub _build_global_stashes {
 
   return $self->{__global_stashes__} if $self->{__global_stashes__};
 
+  # tests shouldn't depend on the user's configuration
+  return {} if $ENV{DZIL_TESTING};
+
   my $stash_registry = $self->{__global_stashes__} = {};
 
   my $config_dir  = Dist::Zilla::Util->_global_config_root;
@@ -146,7 +149,7 @@ Dist::Zilla::App - Dist::Zilla's App::Cmd
 
 =head1 VERSION
 
-version 4.300005
+version 4.300020
 
 =head1 METHODS
 
@@ -161,7 +164,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Ricardo SIGNES.
+This software is copyright (c) 2012 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
