@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Dist::Zilla::App::Command::install;
 {
-  $Dist::Zilla::App::Command::install::VERSION = '4.300006';
+  $Dist::Zilla::App::Command::install::VERSION = '4.300020';
 }
 # ABSTRACT: install your dist
 use Dist::Zilla::App -command;
@@ -36,7 +36,7 @@ Dist::Zilla::App::Command::install - install your dist
 
 =head1 VERSION
 
-version 4.300006
+version 4.300020
 
 =head1 SYNOPSIS
 
@@ -61,7 +61,7 @@ If not specified, calls (roughly):
 
     perl -MCPAN -einstall "."
 
-For more information, look at the L<install|Dist::Zilla/install> method in
+For more information, look at the L<install|Dist::Zilla::Dist::Builder/install> method in
 Dist::Zilla.
 
 =head1 AUTHOR
@@ -70,7 +70,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Ricardo SIGNES.
+This software is copyright (c) 2012 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
