@@ -1,25 +1,30 @@
 use strict;
 use warnings;
 package Dist::Zilla::App::Command::run;
-BEGIN {
-  $Dist::Zilla::App::Command::run::VERSION = '4.200009';
+{
+  $Dist::Zilla::App::Command::run::VERSION = '4.300020';
 }
 # ABSTRACT: run stuff in a dir where your dist is built
-
-
 use Dist::Zilla::App -command;
-use Moose::Autobox;
+
 
 sub abstract { 'run stuff in a dir where your dist is built' }
 
 sub usage_desc {
-  return '%c %o run command [ arg1 arg2 ... ]';
+  return '%c %o [ run command [ arg1 arg2 ... ] ]';
 }
 
 sub execute {
   my ($self, $opts, $args) = @_;
 
-  $self->usage_error("no command to run supplied!") unless @$args;
+  unless (@$args) {
+    my $envname = $^O eq 'MSWin32' ? 'COMSPEC' : 'SHELL';
+    unless ($ENV{$envname}) {
+      $self->usage_error("no command supplied to run and no \$$envname set");
+    }
+    $args = [ $ENV{$envname} ];
+    $self->log("no command supplied to run so using \$$envname: $args->[0]");
+  }
 
   $self->zilla->run_in_build($args);
 }
@@ -35,7 +40,7 @@ Dist::Zilla::App::Command::run - run stuff in a dir where your dist is built
 
 =head1 VERSION
 
-version 4.200009
+version 4.300020
 
 =head1 SYNOPSIS
 
@@ -64,13 +69,16 @@ A command returning with an non-zero error code will left the build directory
 behind for analysis, and C<dzil> will exit with a non-zero status.  Otherwise,
 the build directory will be removed and dzil will exit with status zero.
 
+If no run command is provided, a new default shell is invoked. This can be
+useful for testing your distribution as if it were installed.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Ricardo SIGNES.
+This software is copyright (c) 2012 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
