@@ -1,10 +1,12 @@
 package Dist::Zilla::File::FromCode;
-BEGIN {
-  $Dist::Zilla::File::FromCode::VERSION = '4.200009';
+{
+  $Dist::Zilla::File::FromCode::VERSION = '4.300020';
 }
 # ABSTRACT: a file whose content is (re-)built on demand
 use Moose;
 
+use namespace::autoclean;
+
 
 has code => (
   is  => 'rw',
@@ -23,7 +25,6 @@ sub content {
 
 with 'Dist::Zilla::Role::File';
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
@@ -35,7 +36,7 @@ Dist::Zilla::File::FromCode - a file whose content is (re-)built on demand
 
 =head1 VERSION
 
-version 4.200009
+version 4.300020
 
 =head1 DESCRIPTION
 
@@ -53,7 +54,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Ricardo SIGNES.
+This software is copyright (c) 2012 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
