@@ -1,19 +1,20 @@
 package Dist::Zilla::MVP::Reader::Finder;
-BEGIN {
-  $Dist::Zilla::MVP::Reader::Finder::VERSION = '4.200000';
+{
+  $Dist::Zilla::MVP::Reader::Finder::VERSION = '4.300020';
 }
 use Moose;
 use Config::MVP::Reader 2.101540; # if_none
 extends 'Config::MVP::Reader::Finder';
 # ABSTRACT: the reader for dist.ini files
 
+use namespace::autoclean;
+
 use Dist::Zilla::MVP::Assembler;
 
 sub default_search_path {
   return qw(Dist::Zilla::MVP::Reader Config::MVP::Reader);
 }
 
-no Moose;
 __PACKAGE__->meta->make_immutable;
 1;
 
@@ -26,7 +27,7 @@ Dist::Zilla::MVP::Reader::Finder - the reader for dist.ini files
 
 =head1 VERSION
 
-version 4.200000
+version 4.300020
 
 =head1 AUTHOR
 
@@ -34,7 +35,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2012 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
