@@ -1,6 +1,6 @@
 package Dist::Zilla::MVP::Section;
 {
-  $Dist::Zilla::MVP::Section::VERSION = '4.300005';
+  $Dist::Zilla::MVP::Section::VERSION = '4.300020';
 }
 use Moose;
 extends 'Config::MVP::Section';
@@ -8,7 +8,7 @@ extends 'Config::MVP::Section';
 
 use namespace::autoclean;
 
-use Config::MVP::Section 2.200001; # for not-installed error
+use Config::MVP::Section 2.200002; # for not-installed error
 
 use Moose::Autobox;
 
@@ -27,8 +27,8 @@ after finalize => sub {
   $dzil{$_} = delete $payload{":$_"} for grep { s/\A:// } keys %payload;
 
   if (defined $dzil{version}) {
-    require Version::Requirements;
-    my $req = Version::Requirements->from_string_hash({
+    require CPAN::Meta::Requirements;
+    my $req = CPAN::Meta::Requirements->from_string_hash({
       $plugin_class => $dzil{version}
     });
 
@@ -45,7 +45,7 @@ after finalize => sub {
     }
   }
 
-  $plugin_class->register_component($name, $arg, $self);
+  $plugin_class->register_component($name, \%payload, $self);
 
   return;
 };
@@ -62,7 +62,7 @@ Dist::Zilla::MVP::Section - a standard section in Dist::Zilla's configuration se
 
 =head1 VERSION
 
-version 4.300005
+version 4.300020
 
 =head1 AUTHOR
 
@@ -70,7 +70,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Ricardo SIGNES.
+This software is copyright (c) 2012 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
