@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::AutoPrereq;
 {
-  $Dist::Zilla::Plugin::AutoPrereq::VERSION = '4.300010';
+  $Dist::Zilla::Plugin::AutoPrereq::VERSION = '4.300020';
 }
 use Moose;
 extends 'Dist::Zilla::Plugin::AutoPrereqs';
@@ -18,6 +18,7 @@ before register_component => sub {
 __PACKAGE__->meta->make_immutable;
 1;
 
+
 __END__
 =pod
 
@@ -27,7 +28,11 @@ Dist::Zilla::Plugin::AutoPrereq - (DEPRECATED) the old name for Dist::Zilla::Plu
 
 =head1 VERSION
 
-version 4.300010
+version 4.300020
+
+=head1 SEE ALSO
+
+L<AutoPrereqs|Dist::Zilla::Plugin::AutoPrereqs>
 
 =head1 AUTHOR
 
