@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::MakeMaker;
 {
-  $Dist::Zilla::Plugin::MakeMaker::VERSION = '4.300009';
+  $Dist::Zilla::Plugin::MakeMaker::VERSION = '4.300020';
 }
 
 # ABSTRACT: build a Makefile.PL that uses ExtUtils::MakeMaker
@@ -243,6 +243,7 @@ has __write_makefile_args => (
 __PACKAGE__->meta->make_immutable;
 1;
 
+
 __END__
 =pod
 
@@ -252,7 +253,7 @@ Dist::Zilla::Plugin::MakeMaker - build a Makefile.PL that uses ExtUtils::MakeMak
 
 =head1 VERSION
 
-version 4.300009
+version 4.300020
 
 =head1 DESCRIPTION
 
@@ -277,6 +278,19 @@ set.
 
 You probably won't need to set this option.
 
+=head1 SEE ALSO
+
+Core Dist::Zilla plugins:
+L<@Basic|Dist::Zilla::PluginBundle::Basic>,
+L<ModuleBuild|Dist::Zilla::Plugin::ModuleBuild>,
+L<Manifest|Dist::Zilla::Plugin::Manifest>.
+
+Dist::Zilla roles:
+L<BuildRunner|Dist::Zilla::Role::FileGatherer>,
+L<InstallTool|Dist::Zilla::Role::InstallTool>,
+L<PrereqSource|Dist::Zilla::Role::PrereqSource>,
+L<TestRunner|Dist::Zilla::Role::TestRunner>.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
