@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::Manifest;
 {
-  $Dist::Zilla::Plugin::Manifest::VERSION = '4.300010';
+  $Dist::Zilla::Plugin::Manifest::VERSION = '4.300020';
 }
 # ABSTRACT: build a MANIFEST file
 use Moose;
@@ -49,7 +49,7 @@ Dist::Zilla::Plugin::Manifest - build a MANIFEST file
 
 =head1 VERSION
 
-version 4.300010
+version 4.300020
 
 =head1 DESCRIPTION
 
@@ -57,6 +57,17 @@ If included, this plugin will produce a F<MANIFEST> file for the distribution,
 listing all of the files it contains.  For obvious reasons, it should be
 included as close to last as possible.
 
+This plugin is included in the L<@Basic|Dist::Zilla::PluginBundle::Basic>
+bundle.
+
+=head1 SEE ALSO
+
+Dist::Zilla core plugins:
+L<@Basic|Dist::Zilla::PluginBundle::Manifest>,
+L<ManifestSkip|Dist::Zilla::Plugin::ManifestSkip>.
+
+Other modules: L<ExtUtils::Manifest>.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
