@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::MetaConfig;
 {
-  $Dist::Zilla::Plugin::MetaConfig::VERSION = '4.300010';
+  $Dist::Zilla::Plugin::MetaConfig::VERSION = '4.300020';
 }
 # ABSTRACT: summarize Dist::Zilla configuration into distmeta
 use Moose;
@@ -41,6 +41,7 @@ sub metadata {
 __PACKAGE__->meta->make_immutable;
 1;
 
+
 __END__
 =pod
 
@@ -50,7 +51,7 @@ Dist::Zilla::Plugin::MetaConfig - summarize Dist::Zilla configuration into distm
 
 =head1 VERSION
 
-version 4.300010
+version 4.300020
 
 =head1 DESCRIPTION
 
@@ -61,6 +62,10 @@ package, and version will be included.  Plugins may augment their
 implementation of the L<Dist::Zilla::Role::ConfigDumper> role methods to add
 more data to this dump.
 
+=head1 SEE ALSO
+
+Dist::Zilla roles: L<MetaProvider|Dist::Zilla::Role::MetaProvider>.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
