@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::MetaJSON;
 {
-  $Dist::Zilla::Plugin::MetaJSON::VERSION = '4.300010';
+  $Dist::Zilla::Plugin::MetaJSON::VERSION = '4.300020';
 }
 # ABSTRACT: produce a META.json
 use Moose;
@@ -62,6 +62,7 @@ sub gather_files {
 __PACKAGE__->meta->make_immutable;
 1;
 
+
 __END__
 =pod
 
@@ -71,7 +72,7 @@ Dist::Zilla::Plugin::MetaJSON - produce a META.json
 
 =head1 VERSION
 
-version 4.300010
+version 4.300020
 
 =head1 DESCRIPTION
 
@@ -95,6 +96,19 @@ they are released and adopted.
 
 If you want a fixed version, specify it.
 
+=head1 SEE ALSO
+
+Core Dist::Zilla plugins:
+L<@Basic|Dist::Zilla::PluginBundle::Basic>,
+L<Manifest|Dist::Zilla::Plugin::Manifest>.
+
+Dist::Zilla roles:
+L<FileGatherer|Dist::Zilla::Role::FileGatherer>.
+
+Other modules:
+L<CPAN::Meta>,
+L<CPAN::Meta::Spec>, L<JSON>.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
