@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::MetaNoIndex;
 {
-  $Dist::Zilla::Plugin::MetaNoIndex::VERSION = '4.300010';
+  $Dist::Zilla::Plugin::MetaNoIndex::VERSION = '4.300020';
 }
 # ABSTRACT: Stop CPAN from indexing stuff
 
@@ -19,7 +19,7 @@ my %ATTR_ALIAS = (
 
 sub mvp_aliases {
   my %alias_for;
-  
+
   for my $key (keys %ATTR_ALIAS) {
     $alias_for{ $_ } = $key for @{ $ATTR_ALIAS{$key} };
   }
@@ -55,6 +55,7 @@ sub metadata {
 __PACKAGE__->meta->make_immutable;
 1;
 
+
 __END__
 =pod
 
@@ -64,7 +65,7 @@ Dist::Zilla::Plugin::MetaNoIndex - Stop CPAN from indexing stuff
 
 =head1 VERSION
 
-version 4.300010
+version 4.300020
 
 =head1 SYNOPSIS
 
@@ -128,6 +129,10 @@ Returns a reference to a hash containing the distribution's no_index metadata.
 
 =for Pod::Coverage mvp_aliases mvp_multivalue_args
 
+=head1 SEE ALSO
+
+Dist::Zilla roles: L<MetaProvider|Dist::Zilla::Role::MetaProvider>.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
