@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::MetaResources;
 {
-  $Dist::Zilla::Plugin::MetaResources::VERSION = '4.300009';
+  $Dist::Zilla::Plugin::MetaResources::VERSION = '4.300020';
 }
 
 # ABSTRACT: provide arbitrary "resources" for distribution metadata
@@ -56,6 +56,7 @@ sub metadata {
 __PACKAGE__->meta->make_immutable;
 1;
 
+
 __END__
 =pod
 
@@ -65,7 +66,7 @@ Dist::Zilla::Plugin::MetaResources - provide arbitrary "resources" for distribut
 
 =head1 VERSION
 
-version 4.300009
+version 4.300020
 
 =head1 DESCRIPTION
 
@@ -79,6 +80,12 @@ This plugin adds resources entries to the distribution's metadata.
   repository.web    = http://github.com/dude/project
   repository.type   = git
 
+=head1 SEE ALSO
+
+Dist::Zilla roles: L<MetaProvider|Dist::Zilla::Role::MetaProvider>.
+
+Dist::Zilla plugins on the CPAN: L<GithubMeta|Dist::Zilla::Plugin::GithubMeta>.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
