@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::NextRelease;
 {
-  $Dist::Zilla::Plugin::NextRelease::VERSION = '4.300006';
+  $Dist::Zilla::Plugin::NextRelease::VERSION = '4.300020';
 }
 # ABSTRACT: update the next release number in your changelog
 
@@ -14,6 +14,7 @@ with (
 );
 
 use DateTime 0.44; # CLDR fixes
+use Moose::Util::TypeConstraints;
 use String::Formatter 0.100680 stringf => {
   -as => '_format_version',
 
@@ -27,6 +28,13 @@ use String::Formatter 0.100680 stringf => {
     },
     t => sub { "\t" },
     n => sub { "\n" },
+    E => sub { $_[0]->_user_info('email') },
+    U => sub { $_[0]->_user_info('name')  },
+    T => sub { $_[0]->zilla->is_trial
+                   ? (defined $_[1] ? $_[1] : '-TRIAL') : '' },
+    V => sub { $_[0]->zilla->version
+                . ($_[0]->zilla->is_trial
+                   ? (defined $_[1] ? $_[1] : '-TRIAL') : '') },
   },
 };
 
@@ -55,6 +63,33 @@ has update_filename => (
   default => sub { $_[0]->filename },
 );
 
+has user_stash => (
+  is      => 'ro',
+  isa     => 'Str',
+  default => '%User'
+);
+
+has _user_stash_obj => (
+  is       => 'ro',
+  isa      => maybe_type( class_type('Dist::Zilla::Stash::User') ),
+  lazy     => 1,
+  init_arg => undef,
+  default  => sub { $_[0]->zilla->stash_named( $_[0]->user_stash ) },
+);
+
+sub _user_info {
+  my ($self, $field) = @_;
+
+  my $stash = $self->_user_stash_obj;
+
+  $self->log_fatal([
+    "You must enter your %s in the [%s] section in ~/.dzil/config.ini",
+    $field, $self->user_stash
+  ]) unless $stash and defined(my $value = $stash->$field);
+
+  return $value;
+}
+
 sub section_header {
   my ($self) = @_;
 
@@ -119,6 +154,7 @@ __PACKAGE__->meta->make_immutable;
 1;
 
 
+__END__
 =pod
 
 =head1 NAME
@@ -127,7 +163,7 @@ Dist::Zilla::Plugin::NextRelease - update the next release number in your change
 
 =head1 VERSION
 
-version 4.300006
+version 4.300020
 
 =head1 SYNOPSIS
 
@@ -187,43 +223,77 @@ defaults to C<%-9v %{yyyy-MM-dd HH:mm:ss VVVV}d>
 
 the timezone to use when generating the date;  defaults to I<local>
 
+=item user_stash
+
+the name of the stash where the user's name and email address can be found;
+defaults to C<%User>
+
 =back
 
-The module allows the following sprintf-like format codes in the format:
+The module allows the following sprintf-like format codes in the C<format>:
 
 =over 4
 
-=item *
+=item C<%v>
 
-v - the version of the dist
+The distribution version
 
-=item *
+=item C<%{-TRIAL}T>
 
-d - the CLDR format for L<DateTime>
+Expands to -TRIAL (or any other supplied string) if this
+is a trial release, or the empty string if not.  A bare C<%T> means
+C<%{-TRIAL}T>.
 
-=item *
+=item C<%{-TRIAL}V>
 
-n - a newline
+Equivalent to C<%v%{-TRIAL}T>, to allow for the application of modifiers such
+as space padding to the entire version string produced.
 
-=item *
+=item C<%{CLDR format}d>
 
-t - a tab
+The date of the release.  You can use any CLDR format supported by
+L<DateTime>.  You must specify the format; there is no default.
+
+=item C<%U>
+
+The name of the user making this release (from C<user_stash>).
+
+=item C<%E>
+
+The email address of the user making this release (from C<user_stash>).
+
+=item C<%n>
+
+A newline
+
+=item C<%t>
+
+A tab
 
 =back
 
+=head1 SEE ALSO
+
+Core Dist::Zilla plugins:
+L<AutoVersion|Dist::Zilla::Plugin::AutoVersion>,
+L<PkgVersion|Dist::Zilla::Plugin::PkgVersion>,
+L<PodVersion|Dist::Zilla::Plugin::PodVersion>.
+
+Dist::Zilla roles:
+L<AfterRelease|Dist::Zilla::Plugin::AfterRelease>,
+L<FileMunger|Dist::Zilla::Role::FileMunger>,
+L<TextTemplate|Dist::Zilla::Role::TextTemplate>.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Ricardo SIGNES.
+This software is copyright (c) 2012 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-
-__END__
-
