@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::PkgVersion;
 {
-  $Dist::Zilla::Plugin::PkgVersion::VERSION = '4.300006';
+  $Dist::Zilla::Plugin::PkgVersion::VERSION = '4.300020';
 }
 # ABSTRACT: add a $VERSION to your packages
 use Moose;
@@ -94,6 +94,7 @@ sub munge_perl {
 __PACKAGE__->meta->make_immutable;
 1;
 
+
 __END__
 =pod
 
@@ -103,7 +104,7 @@ Dist::Zilla::Plugin::PkgVersion - add a $VERSION to your packages
 
 =head1 VERSION
 
-version 4.300006
+version 4.300020
 
 =head1 SYNOPSIS
 
@@ -133,13 +134,24 @@ C<package> keyword and the package name, like:
 This sort of declaration is also ignored by the CPAN toolchain, and is
 typically used when doing monkey patching or other tricky things.
 
+=head1 SEE ALSO
+
+Core Dist::Zilla plugins:
+L<PodVersion|Dist::Zilla::Plugin::PodVersion>,
+L<AutoVersion|Dist::Zilla::Plugin::AutoVersion>,
+L<NextRelease|Dist::Zilla::Plugin::NextRelease>.
+
+Other Dist::Zilla plugins:
+L<OurPkgVersion|Dist::Zilla::Plugin::OurPkgVersion> inserts version
+numbers using C<our $VERSION = '...';> and without changing line numbers
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Ricardo SIGNES.
+This software is copyright (c) 2012 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
