@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::PodVersion;
 {
-  $Dist::Zilla::Plugin::PodVersion::VERSION = '4.300005';
+  $Dist::Zilla::Plugin::PodVersion::VERSION = '4.300020';
 }
 # ABSTRACT: add a VERSION head1 to each Perl document
 use Moose;
@@ -70,6 +70,7 @@ sub munge_pod {
 __PACKAGE__->meta->make_immutable;
 1;
 
+
 __END__
 =pod
 
@@ -79,7 +80,7 @@ Dist::Zilla::Plugin::PodVersion - add a VERSION head1 to each Perl document
 
 =head1 VERSION
 
-version 4.300005
+version 4.300020
 
 =head1 DESCRIPTION
 
@@ -88,13 +89,20 @@ distribution, indicating the version of the dist being built.  This section is
 added after C<=head1 NAME>.  If there is no such section, the version section
 will not be added.
 
+=head1 SEE ALSO
+
+Core Dist::Zilla plugins:
+L<PkgVersion|Dist::Zilla::Plugin::PkgVersion>,
+L<AutoVersion|Dist::Zilla::Plugin::AutoVersion>,
+L<NextRelease|Dist::Zilla::Plugin::NextRelease>.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Ricardo SIGNES.
+This software is copyright (c) 2012 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
