@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::RemovePrereqs;
 {
-  $Dist::Zilla::Plugin::RemovePrereqs::VERSION = '4.300006';
+  $Dist::Zilla::Plugin::RemovePrereqs::VERSION = '4.300020';
 }
 # ABSTRACT: a plugin to remove gathered prereqs
 use Moose;
@@ -68,7 +68,7 @@ Dist::Zilla::Plugin::RemovePrereqs - a plugin to remove gathered prereqs
 
 =head1 VERSION
 
-version 4.300006
+version 4.300020
 
 =head1 SYNOPSIS
 
@@ -81,13 +81,19 @@ In your F<dist.ini>:
 This will remove any prerequisite of any type from any prereq phase.  This is
 useful for eliminating incorrectly detected prereqs.
 
+=head1 SEE ALSO
+
+Dist::Zilla plugins:
+L<Prereqs|Dist::Zilla::Plugin::Prereqs>,
+L<AutoPrereqs|Dist::Zilla::Plugin::AutoPrereqs>.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Ricardo SIGNES.
+This software is copyright (c) 2012 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
