@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::Classic;
 {
-  $Dist::Zilla::PluginBundle::Classic::VERSION = '4.300009';
+  $Dist::Zilla::PluginBundle::Classic::VERSION = '4.300020';
 }
 # ABSTRACT: the classic (old) default configuration for Dist::Zilla
 use Moose;
@@ -38,6 +38,8 @@ __PACKAGE__->meta->make_immutable;
 1;
 
 
+
+__END__
 =pod
 
 =head1 NAME
@@ -46,7 +48,7 @@ Dist::Zilla::PluginBundle::Classic - the classic (old) default configuration for
 
 =head1 VERSION
 
-version 4.300009
+version 4.300020
 
 =head1 DESCRIPTION
 
@@ -131,6 +133,10 @@ L<Dist::Zilla::Plugin::UploadToCPAN>
 
 =back
 
+=head1 SEE ALSO
+
+L<@Basic|Dist::Zilla::PluginBundle::Basic>
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
@@ -144,7 +150,3 @@ the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-
-__END__
-
-
