@@ -1,17 +1,17 @@
 package Dist::Zilla::Prereqs;
 {
-  $Dist::Zilla::Prereqs::VERSION = '4.300005';
+  $Dist::Zilla::Prereqs::VERSION = '4.300020';
 }
 # ABSTRACT: the prerequisites of a Dist::Zilla distribution
 use Moose;
 use Moose::Autobox;
 use MooseX::Types::Moose qw(Bool HashRef);
 
-use CPAN::Meta::Prereqs 2.101390;
+use CPAN::Meta::Prereqs 2.120630; # add_string_requirement
 use Hash::Merge::Simple ();
 use Path::Class ();
 use String::RewritePrefix;
-use Version::Requirements;
+use CPAN::Meta::Requirements 2.121; # requirements_for_module
 
 use namespace::autoclean;
 
@@ -41,7 +41,7 @@ sub register_prereqs {
   my $req = $self->requirements_for($phase, $type);
 
   while (my ($package, $version) = each %prereq) {
-    $req->add_minimum($package, $version);
+    $req->add_string_requirement($package, $version || 0);
   }
 
   return;
@@ -59,7 +59,7 @@ Dist::Zilla::Prereqs - the prerequisites of a Dist::Zilla distribution
 
 =head1 VERSION
 
-version 4.300005
+version 4.300020
 
 =head1 DESCRIPTION
 
@@ -123,7 +123,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Ricardo SIGNES.
+This software is copyright (c) 2012 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
