@@ -1,15 +1,16 @@
 package Dist::Zilla::Role::AfterRelease;
-BEGIN {
-  $Dist::Zilla::Role::AfterRelease::VERSION = '4.200009';
+{
+  $Dist::Zilla::Role::AfterRelease::VERSION = '4.300020';
 }
 # ABSTRACT: something that runs after release is mostly complete
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
+use namespace::autoclean;
+
 
 requires 'after_release';
 
-no Moose::Role;
 1;
 
 __END__
@@ -21,7 +22,7 @@ Dist::Zilla::Role::AfterRelease - something that runs after release is mostly co
 
 =head1 VERSION
 
-version 4.200009
+version 4.300020
 
 =head1 DESCRIPTION
 
@@ -34,7 +35,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Ricardo SIGNES.
+This software is copyright (c) 2012 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
