@@ -1,8 +1,7 @@
 package Dist::Zilla::Role::BuildPL;
-BEGIN {
-  $Dist::Zilla::Role::BuildPL::VERSION = '4.200009';
+{
+  $Dist::Zilla::Role::BuildPL::VERSION = '4.300020';
 }
-
 use Moose::Role;
 
 with qw(
@@ -11,6 +10,8 @@ with qw(
   Dist::Zilla::Role::TestRunner
 );
 
+use namespace::autoclean;
+
 sub build {
   my $self = shift;
 
@@ -45,7 +46,7 @@ Dist::Zilla::Role::BuildPL - Common ground for Build.PL based builders
 
 =head1 VERSION
 
-version 4.200009
+version 4.300020
 
 =head1 DESCRIPTION
 
@@ -57,7 +58,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Ricardo SIGNES.
+This software is copyright (c) 2012 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
