@@ -1,6 +1,6 @@
 package Dist::Zilla::Tester;
 {
-  $Dist::Zilla::Tester::VERSION = '4.300003';
+  $Dist::Zilla::Tester::VERSION = '4.300020';
 }
 use Moose;
 extends 'Dist::Zilla::Dist::Builder';
@@ -38,7 +38,7 @@ sub minter { 'Dist::Zilla::Tester::_Minter' }
 {
   package Dist::Zilla::Tester::_Role;
 {
-  $Dist::Zilla::Tester::_Role::VERSION = '4.300003';
+  $Dist::Zilla::Tester::_Role::VERSION = '4.300020';
 }
   use Moose::Role;
 
@@ -84,7 +84,7 @@ sub minter { 'Dist::Zilla::Tester::_Minter' }
 {
   package Dist::Zilla::Tester::_Builder;
 {
-  $Dist::Zilla::Tester::_Builder::VERSION = '4.300003';
+  $Dist::Zilla::Tester::_Builder::VERSION = '4.300020';
 }
   use Moose;
   extends 'Dist::Zilla::Dist::Builder';
@@ -164,7 +164,7 @@ sub minter { 'Dist::Zilla::Tester::_Minter' }
     return $self->$orig($target);
   };
 
-  around release => sub {
+  around ['test', 'release'] => sub {
     my ($orig, $self) = @_;
 
     # XXX: We *must eliminate* the need for this!  It's only here because right
@@ -180,7 +180,7 @@ sub minter { 'Dist::Zilla::Tester::_Minter' }
 {
   package Dist::Zilla::Tester::_Minter;
 {
-  $Dist::Zilla::Tester::_Minter::VERSION = '4.300003';
+  $Dist::Zilla::Tester::_Minter::VERSION = '4.300020';
 }
   use Moose;
   extends 'Dist::Zilla::Dist::Minter';
@@ -271,7 +271,7 @@ Dist::Zilla::Tester - a testing-enabling stand-in for Dist::Zilla
 
 =head1 VERSION
 
-version 4.300003
+version 4.300020
 
 =head1 AUTHOR
 
@@ -279,7 +279,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Ricardo SIGNES.
+This software is copyright (c) 2012 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
